import numpy as np

import vhacdx as pv


def test_basic():
    points = np.array(
        [
            [-0.5, -0.5, -0.5],
            [-0.5, -0.5, 0.5],
            [-0.5, 0.5, 0.5],
            [-0.5, 0.5, -0.5],
            [0.5, -0.5, -0.5],
            [0.5, 0.5, -0.5],
            [0.5, 0.5, 0.5],
            [0.5, -0.5, 0.5],
        ],
        dtype=np.float32,
    )

    faces = np.array(
        [
            3,
            0,
            1,
            3,
            3,
            2,
            3,
            1,
            3,
            4,
            5,
            7,
            3,
            6,
            7,
            5,
            3,
            0,
            4,
            1,
            3,
            7,
            1,
            4,
            3,
            3,
            2,
            5,
            3,
            6,
            5,
            2,
            3,
            0,
            3,
            4,
            3,
            5,
            4,
            3,
            3,
            1,
            7,
            2,
            3,
            6,
            2,
            7,
        ],
        dtype=np.int64,
    )

    output = pv.compute_vhacd(points, faces)

    assert isinstance(output, list)
    assert len(output) == 1
    assert len(output[0]) == 2

    # expand the first result
    vertices, faces = output[0]

    # should be floating point ndarray
    assert isinstance(vertices, np.ndarray)
    assert vertices.dtype.kind == "f"

    # should be unsigned int ndarray
    assert isinstance(faces, np.ndarray)
    assert faces.dtype.kind == "u"

    assert vertices.shape == (8, 3)
    assert faces.shape == (12, 3)


def test_import():
    # check that the version is a string and roughly semantic-version
    assert pv.__version__.count(".") >= 2


if __name__ == "__main__":
    test_basic()
    test_import()



# Available at setup time due to pyproject.toml
import os

from pybind11.setup_helpers import Pybind11Extension, build_ext
from setuptools import setup

# get version from pyproject.toml to pass in to build macro
with open(
    os.path.abspath(os.path.join(os.path.dirname(__file__), "pyproject.toml"))
) as f:
    __version__ = next(L.split("=")[1].strip().strip('"') for L in f if "version" in L)


# The main interface is through Pybind11Extension.
# * You can add cxx_std=11/14/17, and then build_ext can be removed.
# * You can set include_pybind11=false to add the include directory yourself,
#   say from a submodule.

setup(
    ext_modules=[
        Pybind11Extension(
            "vhacdx",
            ["src/vhacdx/main.cpp"],
            # Example: passing in the version to the compiled code
            define_macros=[("VERSION_INFO", __version__)],
        ),
    ],
    cmdclass={"build_ext": build_ext},
)
